/*----------------------------------------------------------------------------
 * Name:    Blinky.c
 * Purpose: Dual Core LED Flasher for K32W042S (M0+ part)
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2017 Keil - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "RTE_Components.h"             // Component selection
#include CMSIS_device_header


/*----------------------------------------------------------------------------
  MUB functions
 *----------------------------------------------------------------------------*/
void MUB_Initialize(void)
{
  PCC1->PCC_MUB |= PCC1_PCC_MUB_CGC(1);                /* enable Clock to MUB */

  MUB->SR  = MU_CR_RIEn_MASK;
  MUB->CR |= MU_CR_RIEn(0xF);                          /* enable all receive interrupts */
}

void MUB_SendMsg(uint32_t regIdx, uint32_t msg)
{
  while ((MUB->SR & MU_SR_TEn((1U << regIdx))) == 0);  /* Wait TX register to be empty. */
  MUB->TR[regIdx] = msg;
}

void MUB_SetFlags(uint32_t flags)
{
  while (MUB->SR & MU_SR_FUP_MASK);                    /* Wait for update finished. */
  MUB->CR = (MUB->CR & ~((MU_CR_GIRn_MASK | MU_CR_NMI_MASK) | MU_CR_Fn_MASK)) | MU_CR_Fn(flags);
}


/*----------------------------------------------------------------------------
  MUB_IRQHandler
 *----------------------------------------------------------------------------*/
void MUB_IRQHandler(void) {
  uint32_t   sr = 0;
  uint32_t   bit = 0;

  sr = MUB->SR;

  switch ((sr & MU_CR_RIEn_MASK) >> MU_CR_RIEn_SHIFT)
  {
    case 8:
      bit = MUB->RR[0];
      MUB_SendMsg(0, bit + 1);
      break;
    default:
      break;
  }

}

// uint32_t startDebug;  // Global varaiable can be used in a debug session.

/*----------------------------------------------------------------------------
  Main Program
 *----------------------------------------------------------------------------*/
int main(void) {

//  while (startDebug == 0U)
//  {
//    __NOP();
//  }

  SystemCoreClockUpdate();

  NVIC_EnableIRQ(MUB_IRQn);                 /* enable MUB interrupt */

  MUB_Initialize();

  MUB_SetFlags(1U);                         /* sinal back that core is started */


  while (1)
  {
    __NOP();
  }
}
